@@ -9,25 +9,12 @@ Description:
 ---------------------------------------------
 """
 
-from .core.store.database import (
-    NAME,
-    DB_PATH,
-    CONFIG_PATH,
-    get_settings,
-    sql,
-    put,
-    has,
-    tb_path,
-    read_ck,
-    read_mysql,
-)
-from .core.qdf import from_polars
-from .factor import Factor
+__version__ = "1.1.17"
 
-__version__ = "1.1.1"
+from typing import Iterable
 
-def update():
 
+def update(tasks: tuple[str] = ("jydata", "mc")):
     """
     通过全局配置文件中的`UPDATES`配置项来更新数据，需要遵循统一编写标准。每个数据源需要定义 `CONFIG` 字典和 `fetch_fn` 方法。
 
@@ -39,13 +26,13 @@ def update():
 
     并在其中定义如下内容：
 
-    >>> import quda
+    >>> import lidb
     >>>
     >>> CONFIG = {'news/tb1': 'SELECT * FROM source_table'}  # SQL 查询语句或其它来源标识
     >>>
     >>> def fetch_fn(tb_name, db_conf):
     ...     query = CONFIG.get(tb_name)
-    ...     return quda.read_mysql(query, db_conf=db_conf)
+    ...     return lidb.read_mysql(query, db_conf=db_conf)
 
     - **Step 2**: 在配置文件中添加配置
 
@@ -65,16 +52,21 @@ def update():
 
     """
 
-    from .core import updater
+    from . import updater
     import ygo
-    import ylog
+    import logair
+    import lidb
 
-    update_settings = get_settings().get("UPDATES")
+    logger = logair.get_logger("quda.update")
+
+    update_settings = lidb.get_settings().get("UPDATES")
     if not update_settings:
-        ylog.warning(f"Missing provider update configuration.")
+        logger.warning(f"Missing provider update configuration.")
         return
     for task, task_conf in update_settings.items():
-        ylog.info(f"[{task} config]: {task_conf}")
+        if task not in tasks:
+            continue
+        logger.info(f"{task} config: {task_conf}")
         mod = ygo.module_from_str(task_conf["mod"])
         for tb_name in mod.CONFIG.keys():
             ygo.delay(updater.submit)(tb_name=tb_name,
@@ -83,17 +75,11 @@ def update():
     updater.do(debug_mode=True)
 
 
-__all__ = [
-    "NAME",
-    "DB_PATH",
-    "CONFIG_PATH",
-    "get_settings",
-    "sql",
-    "put",
-    "has",
-    "tb_path",
-    "read_ck",
-    "read_mysql",
-    "from_polars",
-    "Factor",
-]
+def from_polars(df, index: Iterable[str] = ("date", "time", "asset"), align: bool = False):
+    from .qdf import QDF
+    return QDF(data=df, index=index, align=align)
+
+
+def to_lazy(df, index: Iterable[str] = ("date", "time", "asset"), align: bool = False):
+    from .qdf import LQDF
+    return LQDF(data=df, index=index, align=align)
