@@ -14,8 +14,6 @@ import os
 from dataclasses import dataclass
 from functools import wraps
 
-import pandas as pd
-import polars as pl
 import xcals
 import ygo
 from varname import varname
@@ -173,6 +171,8 @@ class Factor:
         Factor
             一个新的Factor对象，其属性根据当前实例和调用参数初始化。
         """
+        if not kwargs:
+            return self
         frame = self._frame + 1
         newFactor = Factor(*self._depends,
                            fn=ygo.delay(self.fn)(**kwargs),
@@ -261,7 +261,7 @@ class Factor:
                   codes: list[str] | None = None,
                   time: str = '15:00:00',
                   avoid_future: bool = True,
-                  ) -> pd.Series | pd.DataFrame | None:
+                  ):
         """
         获取指定日期和时间的最新数据。
 
@@ -290,8 +290,14 @@ class Factor:
                    end_time: str,
                    freq: str = "1min",
                    codes: list[str] | None = None,
-                   complete_n_workers: int = 5) -> pl.DataFrame:
-        """取值: 指定日期 beg_time -> end_time 的全部值"""
+                   complete_n_workers: int = 5):
+        """
+        取值: 指定日期 beg_time -> end_time 的全部值
+
+        Returns
+        -------
+        polars.DataFrame
+        """
 
     @factor_context
     def get_value_depends(self,
@@ -419,8 +425,14 @@ class Factor:
                            freq: str = "1min",
                            codes: list[str] | None = None,
                            avoid_future: bool = True,
-                           n_jobs: int = 5) -> pl.DataFrame:
-        """获取底层依赖因子 date: beg_time -> end_time 的值"""
+                           n_jobs: int = 5):
+        """
+        获取底层依赖因子 date: beg_time -> end_time 的值
+
+        Returns
+        -------
+        polars.DataFrame
+        """
 
     @factor_context
     def get_history_values(self,
@@ -431,8 +443,14 @@ class Factor:
                            freq: str = "1min",
                            codes: list[str] | None = None,
                            avoid_future: bool = True,
-                           n_jobs: int = 5) -> pl.DataFrame:
-        """获取 beg_date->end_date: beg_time -> end_time 取值"""
+                           n_jobs: int = 5):
+        """
+        获取 beg_date->end_date: beg_time -> end_time 取值
+
+        Returns
+        -------
+        polars.DataFrame
+        """
 
     @factor_context
     def get_history_values_depends(self,
@@ -443,8 +461,14 @@ class Factor:
                                    freq: str = "1min",
                                    codes: list[str] | None = None,
                                    avoid_future: bool = True,
-                                   n_jobs: int = 5) -> pl.DataFrame:
-        """获取底层依赖因子 beg_date->end_date: beg_time -> end_time 的值"""
+                                   n_jobs: int = 5):
+        """
+        获取底层依赖因子 beg_date->end_date: beg_time -> end_time 的值
+
+        Returns
+        -------
+        polars.DataFrame
+        """
 
     def doc(self):
         """
@@ -459,6 +483,7 @@ class Factor:
         # 标题部分
         title = Text(f"{self.name}", style="bold magenta")
         console.print(Panel(title, expand=False))
+        console.print(self.fn.__doc__)
         inspect(self, help=True)
 
         # 示例调用
