@@ -17,6 +17,7 @@ from .factory import (
     Target,
     FilterNotNull,
     TargetFromDifferentTag,
+    Reindex,
 )
 
 from .partial import StandardScaler
@@ -31,4 +32,5 @@ __all__ = [
     "FilterNotNull",
     "StandardScaler",
     "TargetFromDifferentTag",
+    "Reindex",
 ]
\ No newline at end of file
