@@ -17,7 +17,6 @@ import ygo
 from quda.data.zoo.base import fac_components
 
 
-# from quda.factor.core import FactorContext
 
 def test_components():
     test_date = "2025-05-06"
@@ -42,12 +41,39 @@ def test_filter_notindex():
     data = base.fac_filter_notindex(index_codes=["000016", ]).get_value(test_date)
     ylog.info(data.filter(pl.col("cond").is_null()))
 
+def test_get_value():
+    test_date = "2025-05-06"
+    data = base.fac_kline_minute.get_value(date=test_date, time="09:31:00")
+    # data = base.fac_filter.get_value(date=test_date, time="09:00:00")
+    ylog.info(data)
+
+def test_get_history():
+    test_date = "2025-05-06"
+    data = base.fac_filter.get_history(date=test_date, period="-1000d",)
+    ylog.info(data)
+
+def test_ipo():
+    test_date = "2025-05-30"
+    data = base.fac_ipo(days=90).get_value(date=test_date)
+    ylog.info(data)
+
+def test_st():
+    test_date = "2025-05-30"
+    data = base.fac_st.get_value(date=test_date)
+    ylog.info(data)
+
 
 
 if __name__ == '__main__':
+    import quda
     # print(FactorContext.__dataclass_fields__.keys())
     # print(ygo.fn_info(ygo.delay(base.fac_prev_close.fn)(env="rt")))
     # test_base_quote()
     # test_filter()
     # test_components()
-    test_filter_notindex()
\ No newline at end of file
+    # test_filter_notindex()
+    # test_get_value()
+    test_get_history()
+    # test_ipo()
+    # data = quda.sql("select * from mc/stock_kline_minute where date='2025-05-30';")
+    # ylog.info(data.collect())
\ No newline at end of file
